@@ -1,14 +1,18 @@
-from openghg.store.base import BaseStore
-from openghg.types import pathType, multiPathType, resultsType
+import logging
 from pathlib import Path
-from typing import DefaultDict, Dict, Optional, Sequence, Union, Tuple
-from xarray import Dataset
-import numpy as np
+from typing import DefaultDict, Dict, Optional, Sequence, Tuple, Union
 
+import numpy as np
 from openghg.store import DataSchema
+from openghg.store.base import BaseStore
+from openghg.types import multiPathType, pathType, resultsType
+from xarray import Dataset
 
 __all__ = ["ObsSurface"]
 
+logger = logging.getLogger("openghg.store")
+logger.setLevel(logging.DEBUG)  # Have to set level for logger as well as handler
+
 
 class ObsSurface(BaseStore):
     """This class is used to process surface observation data"""
@@ -92,6 +96,7 @@ class ObsSurface(BaseStore):
         sampling_period: Optional[str] = None,
         measurement_type: str = "insitu",
         overwrite: bool = False,
+        verify_site_code: bool = True,
     ) -> Dict:
         """Process files and store in the object store. This function
             utilises the process functions of the other classes in this submodule
@@ -108,16 +113,18 @@ class ObsSurface(BaseStore):
             sampling_period: Sampling period in pandas style (e.g. 2H for 2 hour period, 2m for 2 minute period).
             measurement_type: Type of measurement e.g. insitu, flask
             overwrite: Overwrite previously uploaded data
+            verify_site_code: Verify the site code
         Returns:
             dict: Dictionary of Datasource UUIDs
         """
-        from collections import defaultdict
-        from pandas import Timedelta
         import sys
-        from tqdm import tqdm
-        from openghg.util import load_surface_parser, hash_file, clean_string, verify_site
+        from collections import defaultdict
+
+        from openghg.store import assign_data, datasource_lookup, load_metastore
         from openghg.types import SurfaceTypes
-        from openghg.store import assign_data, load_metastore, datasource_lookup
+        from openghg.util import clean_string, hash_file, load_surface_parser, verify_site
+        from pandas import Timedelta
+        from tqdm import tqdm
 
         if not isinstance(filepath, list):
             filepath = [filepath]
@@ -130,7 +137,7 @@ class ObsSurface(BaseStore):
         # Test that the passed values are valid
         # Check validity of site, instrument, inlet etc in acrg_site_info.json
         # Clean the strings
-        site = verify_site(site=site)
+        site = verify_site(site=site) if verify_site_code else clean_string(site)
         network = clean_string(network)
         inlet = clean_string(inlet)
         instrument = clean_string(instrument)
@@ -172,10 +179,10 @@ class ObsSurface(BaseStore):
 
                 file_hash = hash_file(filepath=data_filepath)
                 if file_hash in obs._file_hashes and overwrite is False:
-                    print(
-                        f"This file has been uploaded previously with the filename : {obs._file_hashes[file_hash]} - skipping."
+                    logger.warning(
+                        "This file has been uploaded previously with the filename : "
+                        f"{obs._file_hashes[file_hash]} - skipping."
                     )
-                    continue
 
                 progress_bar.set_description(f"Processing: {data_filepath.name}")
 
@@ -207,8 +214,8 @@ class ObsSurface(BaseStore):
                     try:
                         ObsSurface.validate_data(value["data"], species=species)
                     except ValueError:
-                        print(
-                            f"ERROR: Unable to validate and store data from file: {data_filepath.name}.",
+                        logger.error(
+                            f"Unable to validate and store data from file: {data_filepath.name}.",
                             f" Problem with species: {species}\n",
                         )
                         validated = False
@@ -239,6 +246,7 @@ class ObsSurface(BaseStore):
                 required_keys = (
                     "species",
                     "site",
+                    "sampling_period",
                     "station_long_name",
                     "inlet",
                     "instrument",
@@ -270,6 +278,9 @@ class ObsSurface(BaseStore):
 
                 progress_bar.update(1)
 
+            logger.info(f"Completed processing: {data_filepath.name}.")
+            logger.info(f"\tUUIDs: {datasource_uuids}")
+
         # Ensure we explicitly close the metadata store
         # as we're using the cached storage method
         metastore.close()
@@ -295,10 +306,11 @@ class ObsSurface(BaseStore):
 
         This data is different in that it contains multiple sites in the same file.
         """
-        from openghg.standardise.surface import parse_aqmesh
-        from openghg.store import assign_data, load_metastore, datasource_lookup
-        from openghg.util import hash_file
         from collections import defaultdict
+
+        from openghg.standardise.surface import parse_aqmesh
+        from openghg.store import assign_data, datasource_lookup, load_metastore
+        from openghg.util import hash_file
         from tqdm import tqdm
 
         data_filepath = Path(data_filepath)
@@ -430,7 +442,7 @@ class ObsSurface(BaseStore):
         Returns:
             Dict or None:
         """
-        from openghg.store import assign_data, load_metastore, datasource_lookup
+        from openghg.store import assign_data, datasource_lookup, load_metastore
         from openghg.util import hash_retrieved_data
 
         obs = ObsSurface.load()
@@ -442,13 +454,13 @@ class ObsSurface(BaseStore):
         seen_before = {next(iter(v)) for k, v in hashes.items() if k in obs._retrieved_hashes}
 
         if len(seen_before) == len(data):
-            print("Note: There is no new data to process.")
+            logger.warning("Note: There is no new data to process.")
             return None
 
         keys_to_process = set(data.keys())
         if seen_before:
             # TODO - add this to log
-            print(f"Note: We've seen {seen_before} before. Processing new data only.")
+            logger.warning(f"Note: We've seen {seen_before} before. Processing new data only.")
             keys_to_process -= seen_before
 
         to_process = {k: v for k, v in data.items() if k in keys_to_process}
